@@ -1,10 +1,8 @@
-# coding: utf-8
-
-from .core import Page, RenderedFile
+from .page import Page
+from .rendered import RenderedFile
 import datetime
 import os
 import pytz
-import shutil
 
 
 class Asset(Page):
